Struct countio::Counter

source ·
pub struct Counter<D> { /* private fields */ }
The Counter<D> struct adds byte counting to any reader or writer.

Implementations

source

impl<D> Counter<D>

source

pub const fn new(inner: D) -> Self

Creates a new Counter<D> with zero read/written bytes.

source

pub const fn with_bytes( reader_bytes: usize, writer_bytes: usize, inner: D, ) -> Self

Creates a new Counter<D> with the specified read/written bytes.

source

pub const fn total_bytes(&self) -> usize

Returns the sum of read and written bytes by the underlying reader/writer.

source

pub const fn reader_bytes(&self) -> usize

Returns the total amount of read bytes by the underlying reader.

source

pub const fn writer_bytes(&self) -> usize

Returns the total amount of written bytes by the underlying writer.

source

pub fn into_inner(self) -> D

Consumes Counter<D> returning the underlying reader/writer.

source

pub fn get_ref(&self) -> &D

Gets a reference to the underlying reader/writer.

source

pub fn get_mut(&mut self) -> &mut D

Gets a mutable reference to the underlying reader/writer.