pub struct Counter<D> { /* private fields */ }Expand description
The Counter<D> struct adds byte counting to any reader or writer.
Implementations
sourceimpl<D> Counter<D>
impl<D> Counter<D>
sourcepub const fn with_bytes(
reader_bytes: usize,
writer_bytes: usize,
inner: D,
) -> Self
pub const fn with_bytes( reader_bytes: usize, writer_bytes: usize, inner: D, ) -> Self
Creates a new Counter<D> with the specified read/written bytes.
sourcepub const fn total_bytes(&self) -> usize
pub const fn total_bytes(&self) -> usize
Returns the sum of read and written bytes by the underlying reader/writer.
sourcepub const fn reader_bytes(&self) -> usize
pub const fn reader_bytes(&self) -> usize
Returns the total amount of read bytes by the underlying reader.
sourcepub const fn writer_bytes(&self) -> usize
pub const fn writer_bytes(&self) -> usize
Returns the total amount of written bytes by the underlying writer.
sourcepub fn into_inner(self) -> D
pub fn into_inner(self) -> D
Consumes Counter<D> returning the underlying reader/writer.